from machine import Pin
import socket

# ファイルエラー時に返すHTML
errhtml = """<!DOCTYPE html>
<html>
    <head> <title>File name error HTML</title> </head>
    <body> 
        <h3>There is no [%s] file</h3>
    </body>
</html>
"""

led = Pin(16, Pin.OUT)     # ピン１６番(GPIO16)をLED出力で割り付ける
sw1 = Pin(0, Pin.IN)       # ピン０番(GPIO0)をスイッチ入力で割り付ける
# 指定されたアドレスファミリ、ソケットタイプ、プロトコル番号を使い、新しいソケットを作成する
addr = socket.getaddrinfo('0.0.0.0', 80)[0][-1]
soc = socket.socket()
soc.bind(addr)   # socketの登録を行う
soc.listen(1)    # 接続を受け入れる事ができる様にします
print('listening on', addr)

while True:
    fname = ""
    form = ""
    ver = "1.0"
    # クライアントの接続を待つ
    cl, addr = soc.accept()
    print('\r\nclient connected from', addr)
    # Requestメッセージを読み取る
    cl_file = cl.makefile('rwb', 0)
    while True:
        bMsg = cl_file.readline()
        print(bMsg)
        if not bMsg or bMsg == b'\r\n':
            break
        sMsg = bMsg.decode()     # バイト列から文字列へ変換
        s = sMsg.rsplit()        # メッセージを分割
        # GET行だけ処理
        if s[0] == 'GET':
            ver = s[2][-3:]      # HTTP/x.xを得る
            # フォームデータの有無をチェック
            if s[1].find('?') != -1:
                s = s[1].split('?')
                fname = s[0][1:]  # HTMLファイル名を得る
                form = s[1]       # フォームデータを得る
            else:
                fname = s[1][1:]  # HTMLファイル名を得る
    # 応答メッセージを返す
    print(fname, form)
    if fname != '':
        try:
            f = open(fname, "rt")
        except OSError:
            # 指定のファイルが無いがほとんどのエラー
            s = 'HTTP/' + ver + ' 200 OK\r\nContent-type: text/html\r\n\r\n'
            cl.send(s.encode())
            response = errhtml % fname
            cl.send(response.encode())
            print(response)
        else:
            s = 'HTTP/' + ver + ' 200 OK\r\nContent-type: text/html\r\n\r\n'
            cl.send(s.encode())
            # HTMLファイルを読み込む
            dt = f.readlines()
            for i in dt:
                print(i, end='')
                if str(i).find('%s') != -1:
                    # スイッチの状態をHTMLに埋め込む
                    if sw1.value() == 1: s = 'OFF'
                    else: s = 'ON'
                    x = str(i) % s
                    cl.send(x.encode())
                else:
                    cl.send(i.encode())
            cl.send(b'\r\n')
            f.close()
            # LEDのON/OFF処理
            if form[4:] == 'on': led.value(0)  # 点灯
            else: led.value(1)                 # 消灯
    # ソケットを閉じる
    cl.close()
